:- module(blending, [compute_blends/6]).

/** <module> Blending algorithm
 *
 *  Implementation of the compute_blends algorithm from the paper
 *  "Algorithmic Aspects of Theory Blending".
 *
 *  @author Ulf Krumnack
 *  @copyright 2014
 *  @license GPL
 */

:- use_module(explore).


%! compute_blends(+Base:list, +Axioms:list, +Init:list,
%!                -MaxCon:list_of_lists, -MinInc:list_of_lists,
%!                +Direction:up_or_down) is det
%
% Implementation of the "compute_blends" procedure from the paper
% "Algorithmic Aspects of Theory Blending".
%
compute_blends(Base, Axioms, Init, MaxCon, MinInc, Direction) :-
    compute_blends(Base, Axioms, Init, [], MaxCon, [], MinInc, Direction).


%! compute_blends(+Base:list, +Axioms:list, +Init:list,
%!                +MaxConIn:list, -MaxConOut:list,
%!                +MinIncIn:list, -MinIncOut:list, Direction) is det
%
% 
compute_blends(_, _, [], MaxCon, MaxCon, MinInc, MinInc, _) :- !.

compute_blends(B, Ax, [T|R], MaxConIn, MaxConOut, MinIncIn, MinIncOut, Option) :-
    explore(B, Ax, T, MaxConIn, MaxConHelp, MinIncIn, MinIncHelp, Option),
    compute_blends(B, Ax, R, MaxConHelp, MaxConOut, MinIncHelp, MinIncOut, Option).
